@@ -26,8 +26,8 @@ class SplitHigherNet(nn.Module):
         y_a, y_b = self.forward(x_a, x_b)
 
 
-        sign_a = torch.max(F.softmax(y_a, dim=-1), dim=-1, keepdim=True)
-        sign_b = torch.max(F.softmax(y_b, dim=-1), dim=-1, keepdim=True)
+        sign_a = torch.max(F.softmax(y_a, dim=-1), dim=-1, keepdim=True)[0]
+        sign_b = torch.max(F.softmax(y_b, dim=-1), dim=-1, keepdim=True)[0]
 
         y = torch.where(sign_a>sign_b, y_a, y_b)
 
